@@ -381,8 +381,8 @@ class PBRMaterial(Material):
         else:
             # non-None values must be a floating point
             emissive = np.array(value, dtype=np.float64).reshape(3)
-            if emissive.min() < -_eps or emissive.max() > (1 + _eps):
-                raise ValueError("all factors must be between 0.0-1.0")
+            if emissive.min() < -_eps :
+                raise ValueError("all factors must be greater than 0.0")
             self._data["emissiveFactor"] = emissive
 
     @property
@@ -682,8 +682,18 @@ class PBRMaterial(Material):
         simple : SimpleMaterial
           Contains material information in a simple manner
         """
-
-        return SimpleMaterial(image=self.baseColorTexture, diffuse=self.baseColorFactor)
+        # `self.baseColorFactor` is really a linear value
+        # so the "right" thing to do here would probably be:
+        #  `diffuse = color.to_rgba(color.linear_to_srgb(self.baseColorFactor))`
+        # however that subtle transformation seems like it would confuse
+        # the absolute heck out of people looking at this. If someone wants
+        # this and has opinions happy to accept that change but otherwise
+        # we'll just keep passing it through as "probably-RGBA-like"
+        return SimpleMaterial(
+            image=self.baseColorTexture,
+            diffuse=self.baseColorFactor,
+            name=self.name,
+        )
 
     @property
     def main_color(self):
